@@ -70,8 +70,6 @@ void DocumentJPEGLoadedImpl::init() {
 		&& orientation!=ImageUtils::NOT_AVAILABLE
 		&& orientation!=ImageUtils::NORMAL)
 	{
-		LOG("jpeg rotating");
-		setImage(ImageUtils::transform(mDocument->image(), orientation), true);
 		d->mJPEGContent.transform(orientation);
 	}
 
@@ -86,7 +84,8 @@ DocumentJPEGLoadedImpl::~DocumentJPEGLoadedImpl() {
 
 void DocumentJPEGLoadedImpl::transform(ImageUtils::Orientation orientation) {
 	d->mJPEGContent.transform(orientation);
-	setImage(ImageUtils::transform(mDocument->image(), orientation), true);
+	setImage(ImageUtils::transform(mDocument->image(), orientation));
+	emitImageRectUpdated();
 }
 
 
@@ -120,6 +119,22 @@ void DocumentJPEGLoadedImpl::setComment(const QString& comment) {
 	d->mJPEGContent.setComment(comment);
 }
 
+QString DocumentJPEGLoadedImpl::aperture() const {
+	return d->mJPEGContent.aperture();
+}
+
+QString DocumentJPEGLoadedImpl::exposureTime() const {
+	return d->mJPEGContent.exposureTime();
+}
+
+QString DocumentJPEGLoadedImpl::iso() const {
+	return d->mJPEGContent.iso();
+}
+
+QString DocumentJPEGLoadedImpl::focalLength() const {
+	return d->mJPEGContent.focalLength();
+}
+
 Document::CommentState DocumentJPEGLoadedImpl::commentState() const {
 	return Document::WRITABLE;
 }
