@@ -63,9 +63,8 @@ GVDirPart::GVDirPart(QWidget* parentWidget, const char* /*widgetName*/, QObject*
 		     const QStringList &) : KParts::ReadOnlyPart( parent, name )  {
 	GVDirFactory::instance()->iconLoader()->addAppDir( "gwenview");
 	setInstance( GVDirFactory::instance() );
-	KGlobal::locale()->insertCatalogue( "gwenview" );
-
-	Cache::instance()->ref();
+	KGlobal::locale()->insertCatalogue("gwenview");
+	KGlobal::locale()->setActiveCatalogue("gwenview");
 
 	mBrowserExtension = new GVDirPartBrowserExtension(this);
 
@@ -88,13 +87,14 @@ GVDirPart::GVDirPart(QWidget* parentWidget, const char* /*widgetName*/, QObject*
 	setWidget(mSplitter);
 
 	KStdAction::saveAs( mDocument, SLOT(saveAs()), actionCollection(), "saveAs" );
+	new KAction(i18n("Rotate &Left"), "rotate_ccw", CTRL + Key_L, this, SLOT(rotateLeft()), actionCollection(), "rotate_left");
 	new KAction(i18n("Rotate &Right"), "rotate_cw", CTRL + Key_R, this, SLOT(rotateRight()), actionCollection(), "rotate_right");
 
 	connect(mFileViewController, SIGNAL(requestContextMenu(const QPoint&, bool)),
 		mBrowserExtension, SLOT(openFileViewContextMenu(const QPoint&, bool)) );
 
 	connect(mFileViewController, SIGNAL(urlChanged(const KURL&)),
-		this, SLOT(urlChanged(const KURL&)) );
+		mDocument, SLOT(setURL(const KURL&)) );
 
 	connect(mFileViewController, SIGNAL(directoryChanged(const KURL&)),
 		this, SLOT(directoryChanged(const KURL&)) );
@@ -106,7 +106,7 @@ GVDirPart::GVDirPart(QWidget* parentWidget, const char* /*widgetName*/, QObject*
 		mBrowserExtension, SLOT(openImageViewContextMenu(const QPoint&)) );
 
 	connect(mSlideShow, SIGNAL(nextURL(const KURL&)),
-		this, SLOT(urlChanged(const KURL&)) );
+		this, SLOT(slotSlideShowChanged(const KURL&)) );
 
 	connect(mDocument, SIGNAL(loaded(const KURL&)),
 		this, SLOT(loaded(const KURL&)) );
@@ -128,7 +128,6 @@ GVDirPart::~GVDirPart() {
 	GVDirPartConfig::setFileViewWidth(mFileViewController->width());
 	GVDirPartConfig::writeConfig();
 	delete mSlideShow;
-	Cache::instance()->deref();
 }
 
 
@@ -217,6 +216,10 @@ void GVDirPart::print() {
 	}
 }
 
+void GVDirPart::rotateLeft() {
+	mDocument->transform(ImageUtils::ROT_270);
+}
+
 void GVDirPart::rotateRight() {
 	mDocument->transform(ImageUtils::ROT_90);
 }
@@ -226,7 +229,7 @@ void GVDirPart::directoryChanged(const KURL& dirURL) {
 	emit mBrowserExtension->openURLRequest(dirURL);
 }
 
-void GVDirPart::urlChanged(const KURL& url) {
+void GVDirPart::slotSlideShowChanged(const KURL& url) {
 	mDocument->setURL( url );
 	mFileViewController->setFileNameToSelect( url.filename());
 }
